# PolyChemPrint3
Free and Open Source 3D Printer control software (Perl) targeted at 
Research Users (Polymer/Paste/BioPrinting)
Written in/for Python 3.3+

This software was initially written by Bijal Patel from 2017-2019 as 
an object-oriented cross-platform tool and successor to 
PolyPrint, a Perl script.

Within our lab (Diao Group at the University of Illinois 
http://diao.scs.illinois.edu/Diao_Lab/Home.html) 
we have succesfully used it to print solutions for organic 
semiconductors/conductors, polymer photonics, hydrogels, chocolate, etc. 

The software is written to be convenient for researchers with 
features like automatic data logging, parameterized shapes, and 
convenient macros.

Please cite the following papers if you make use of this software 
in your research!
> [Paper Submitted]
> 
